==> ws-v3.80.3-src.tar.gz: ws-v3.80-3/include/WSCvthread.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVTHREAD_H
#define WSCVTHREAD_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvthread_VER  1000
#include <WSDthread.h>

class WSCvthread   :public WSCngbase{
  protected:
    WSDthread*  _thread;

    static void* _thread_proc(WSDthread*,void*);
    static void _callback_proc(WSDthread*,void*);

  public:

    WSCvthread(WSCbase* base, char* name);
    virtual ~WSCvthread();
    long executeThread();
    long sendActivateEvent();
    virtual void onActivate();
    virtual void onThreadStarted();

    WSMFguiClassDef(WSCvthread,WSCngbase);
    WSMFversionDef(WSCvthread);
};

#endif //WSCVTHREAD_H

==> ws-v3.93.2-src.tar.gz: ws-v3.93-2/include/WSCvthread.h <==
//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCVTHREAD_H
#define WSCVTHREAD_H

#include <WScom.h>
#include <WSCngbase.h>
#include <WSDimage.h>
#define WSCvthread_VER  1000
#include <WSDthread.h>

class WSCvthread   :public WSCngbase{
  protected:
    WSDthread*  _thread;

    WSDLEX32 static void* _thread_proc(WSDthread*,void*);
    WSDLEX32 static void _callback_proc(WSDthread*,void*);

  public:

    WSDLEX32 WSCvthread(WSCbase* base, char* name);
    WSDLEX32 virtual ~WSCvthread();
    WSDLEX32 long executeThread();
    WSDLEX32 long sendActivateEvent();
    WSDLEX32 virtual void onActivate();
    WSDLEX32 virtual void onThreadStarted();

    WSMFguiClassDef(WSCvthread,WSCngbase);
    WSMFversionDef(WSCvthread);
};

#endif //WSCVTHREAD_H
